package com.ruoyi.web.bst;

import com.ruoyi.bst.store.domain.Store;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.bst.store.domain.dto.StoreStockInDTO;
import com.ruoyi.bst.store.service.IStoreService;
import com.ruoyi.bst.store.service.StoreConverter;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 入库Controller
 *
 * @author ruoyi
 * @date 2024-12-19
 */
@RestController
@RequestMapping("/bst/store")
public class StoreController extends BaseController
{
    @Autowired
    private IStoreService storeService;

    @Autowired
    private StoreConverter storeConverter;

    /**
     * 查询入库列表
     */
    @PreAuthorize("@ss.hasPermi('bst:store:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(StoreQuery query)
    {
        startPage();
        startOrderBy();
        List<StoreVO> list = storeService.selectStoreList(query);
        return getDataTable(list);
    }

    /**
     * 导出入库列表
     */
    @PreAuthorize("@ss.hasPermi('bst:store:export')")
    @Log(title = "入库", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StoreQuery query)
    {
        List<StoreVO> list = storeService.selectStoreList(query);
        ExcelUtil<StoreVO> util = new ExcelUtil<StoreVO>(StoreVO.class);
        util.exportExcel(response, list, "入库数据");
    }

    /**
     * 获取入库详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:store:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(storeService.selectStoreById(id));
    }

    /**
     * 新增入库
     */
    @PreAuthorize("@ss.hasPermi('bst:store:add')")
    @Log(title = "入库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) StoreVO store)
    {
        Store po = storeConverter.toPOByCreate(store, getLoginUser().getUser());
        return toAjax(storeService.insertStore(po));
    }

    @PreAuthorize("@ss.hasPermi('bst:store:stockIn')")
    @Log(title = "入库", businessType = BusinessType.STOCK_IN)
    @PutMapping("/stockIn")
    public AjaxResult stockIn(@RequestBody @Validated StoreStockInDTO dto) {
        return toAjax(storeService.stockIn(dto.getId(), dto.getStoreNum(), getLoginUser().getUser()));
    }

    /**
     * 删除入库
     */
    @PreAuthorize("@ss.hasPermi('bst:store:remove')")
    @Log(title = "入库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        return toAjax(storeService.logicDel(id));
    }

}
